#
# spec file for package ft2-clone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ft2-clone
Version:        1.90
Release:        1.1
Summary:        Fasttracker II clone
License:        BSD-3-Clause AND CC-BY-NC-SA-4.0
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://16-bits.org/ft2.php
#Git-Clone:     https://github.com/8bitbubsy/ft2-clone.git
Source:         https://github.com/8bitbubsy/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  icns-utils
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(sdl2)
Provides:       bundled(rtmidi)

%description
Multi-platform clone of the classic music making software
Fasttracker II. It can load XM, MOD, S3M, STM module files.

%prep
%setup -q
icns2png -x "release/macos/ft2-clone-macos.app/Contents/Resources/ft2-clone-macos.icns"
rm -R src/libflac

%build
%cmake -DEXTERNAL_LIBFLAC=ON
%cmake_build

%install
%cmake_install

install -Dpm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dpm 0644 ft2-clone-macos_512x512x32.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%license LICENSE LICENSES.txt src/gfxdata/bmp/LICENSE.txt
%doc README.md release/problems.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Mon Dec  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.90
  * Fixed: The Nibbles game broke in v1.89 (snake food was no
    longer visible)
* Sun Dec  8 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.89
  * Fixed a possible crash on macOS (and possibly Linux) when
    loading a module whose filename includes special non-ASCII
    characters.
  * Added a "Default audio device" option when selecting
    input/output audio devices in the config screen. This option
    has a few edge-case bugs, though.
  * Added an experimental Impulse Tracker module loader. This
    should only be used to extract patterns/instruments/samples,
    as there are severe conversion errors when this format is
    converted to XM under load. WARNING: This loader has not
    been thoroughly tested, and may cause a crash!
  * Fixed a bug with the tracker scopes where the sample would
    sometimes not be isplayed correctly during a sample/note
    trigger.
  * Replaced the Gaussian (SNES) interpolator with a 6-point
    cubic Hermite option. The Gaussian interpolator was very niche
    anyway, and as it sounded quite filtered, I think the vast
    majority of users wouldn't see a use for it.
  * Added a few missing Norwegian/Danish alphabet letters to the
    main font (code page is now 850 instead of 437).
  * Show extra digits (when space for them) in the C-4 Hz string
    in the instrument editor screen.
  * Again, slightly improved the interpolation method for the
    tracker scopes in "Lined" mode (when using the cubic/sinc
    interpolators)
  * Slightly increased the contrast for the sample editor's loop
    pin lines.
* Thu Nov  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.88
  * Added an experimental .BRR (Super Nintendo) sample loader.
    Thanks to astriid for suggesting this (and coming up with
    some base code).
  * The tracker scopes now show a waveform that is more correct
    when using interpolation mode "No interpolation" and
    "Linear (FT2)".
  * Fixed: The "Gaussian (SNES)" interpolation option had a small
    delay of one input sample point. Not a big deal, but I
    corrected it anyway.
* Sun Nov  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.87
  * Fixed: Stereo FLAC samples with a bitdepth of 24 didn't import
    correctly if you chose to convert to mono.
  * Added a Super Nintendo interpolation option ("Gaussian").
  * Fixed wrong tuning when importing Gravis Ultrasound .PAT patch
    files.
  * Slightly improved the interpolation method for the tracker
    scopes in "Lined" mode.
  * Updated the help text to reflect the new interpolation option.
  * Code cleanup.
* Tue Sep 17 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.86
  * Fixed: The extended pattern editor had a status bar redraw
    issue if you had disabled "Framework" in Config -> Layout.
- Update to version 1.85
  * Waving logo in the about screen.
  * Small optimization of the "volume change" function in the
    sample editor.
* Sat May 11 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.84
  Bugfix release
  * There was a bug in v1.83 making you unable to play-test (jam)
    samples at all while the pattern editor was hidden.
* Sat May 11 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.83
  * Now you cannot edit pattern notes/data while the pattern editor
    is not visible. This further prevents accidental song edits.
  * While in extended pattern editor mode, show a status bar with
    global volume, pattern edit status (to see if you are editing),
    and time elapsed
  * It was not possible to issue a Note Insert (Insert key) or Line
    Insert (Shift+Insert) on some keyboards. Added extra
    keybindings:
    + Ctrl+Return = Insert Note (same as Insert)
    + Ctrl+Shift+Return = Insert Line (same as Shift+Insert)
  * Updated the Keybindings help text to reflect the extra
    keybindings
* Fri Apr 12 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.82
  * Fixed: MIDI was actually not working in v1.81.
  * Fixed: Possible crash on startup or on exit (related to MIDI).
* Tue Apr  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.81
  * Rewrote some of the MIDI init/close code, as it looked like
    it could be buggy.
- Update to version 1.80
  * Doing note transpose on the whole song wouldn't count
    overflowing notes properly (it would sometimes not show a
    warning message first)
* Mon Mar 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.79
  * Fullscreen mode code has been refactored, as I apparently had
    coded it the wrong way. "Stretched" mode always fills the
    whole screen now too, and other issues may have been fixed as
    well.
* Sun Mar 17 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.78
  * Fixed: It was possible to deadlock the tracker by attempting
    to load samples that had a filesize of zero bytes, or if the
    sample was in use by another program.
  * Fullscreen mode has received more bugfixes.
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 1.77.1:
  * The 32-point sinc resampling interpolator was reduced to
    16-point again because of the trade-off not being big enough,
    and it was slightly wrongly implemented and would alias a
    little bit in some cases. I'll implement a better sinc
    interpolator in the future, if I ever stumble across a nice
    and simple implementation. Please let me know if you have
    one!
* Mon Mar 11 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.77
  * The 32-point sinc resampling interpolator was reduced to
    16-point again because of the trade-off not being big enough,
    and it was slightly wrongly implemented and would alias a
    little bit in some cases. I'll implement a better sinc
    interpolator in the future, if I ever stumble across a nice
    and simple implementation.
* Fri Feb 23 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.76
  * The 16-point sinc resampling interpolator has been upgraded to
    32-point for better sound quality in the tracker (if you have
    selected "Sinc (32 point)"). This interpolator is so good that
    a lot of old XM tunes will sound muddy because of lo-fi samples
    I recommend that you experiment with the choice of
    interpolators. "Cubic spline" is a good choice if you listen
    to a wide variety of XMs, while "Sinc (32 point)" is the best
    option if you create your own tunes using hi-fi samples, or if
    you mostly listen to XMs with hi-fi samples (or if you can
    accept a muddy/filtered sound from lo-fi samples).
  * Removed text fading from "about screen" (more is less)
* Sat Feb 17 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.75
  * Note transpose (block), instrument remapping (block), Cut Block (ALT+F3)
    and Copy Block (ALT+F4) had issues if you had made a block selection in
    the last channel/track in a pattern.
    Thanks to Roz for finding this and reporting it, and sorry to all the people
    who may have had this bug without knowing what was going on!
* Sat Dec 16 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.74
  * Added a cubic spline audio interpolation option.
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.73
  * Sample editor: Shift + mouse-wheel = scroll sample data view
- Update to version 1.72
  * Block Cut (ALT+F3) and Block Copy (ALT+F4) was broken in v1.70
* Wed Oct  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.71
  * CTRL+A/ALT+A keybindings were swapped.
- Update to version 1.70
  * Bugfix: Shrink Pattern ("Srnk.") could lead to a pattern
    length of 0.
  * Better variable sanitation for some pattern editing routines,
    may (?) prevent some rare crashes.
  * CTRL+F5 (Paste Pattern) had wrong button names in its
    message box when asking to adjust the pattern length after
    pasting.
  * Changed the above message box text to be easier to understand.
  * Removed audio dithering for 16-bit audio bit depth mode. It
    seemed to be wrongly implemented anyway.
  * Some small changes done to the about screen.
  * Code cleanup.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.69
  Bugfixes
  * The 'pattern expand' feature was heavily broken and would mess
    up the pattern data (and potentially crash the program).
  * The program crash message could overflow and not show the full
    text on some system
- Update to version 1.68
  * De-minimize window (if minimized) and set focus after
    drag n' drop of file.
- Update to version 1.67
  * The song-to-WAV export screen now defaults to the tracker's bit
    depth and audio rate. This was actually the behavior for
    earlier versions of the FT2 clone, but I decided to change it
    back.
  * The song-to-WAV exporter now allows rates up to 384kHz.
  * Alpha-based fade in for the about screen content.
  * Some small text string changes (config and song-to-WAV export
    screen)
* Sat Apr 15 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.66
  * Added a 16 point sinc interpolation option (higher quality).
  * Changed some settings for the default configuration:
    1. Palette theme = Dark mode
    2. Scopes = Lined
    Note: Your existing configuration will not be changed!
  * Changed the layout a little in the Config section (Audio /
    "I/O Devices")
  * Removed the 192kHz audio output setting. This was a bit
    extreme to begin with. Note: You can still select this rate
    when exporting songs to WAV.
* Sat Mar  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.65
  * Quick fix for volume ramp delta.
- Update to version 1.64
  * Increased number of precision bits for song BPM, playback time
    counter and audio->video syncing. This is a minor change and
    does very little in practice as the previous precision was
    already quite good.
  * Audio/video sync timestamps are reset every half an hour to
    prevent possible sync drifting after several hours of playing
    a song without a single song stop (resets timestamp) in-between
  * The HPC timers are reset every half an hour instead of every
    hour. Video (if no vsync) and the scopes use these timers.
  * Small code refactor for how the song is timed/ticked. Longer
    song-to-WAV renders may have a filesize change of a few bytes,
    but this is actually more correct.
* Tue Feb 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.63
- Build with system-wide flac
- Use pkg-config style dependencies
  Sat Oct  9 14:04:02 UTC 2021 - Arachnos
- Initial package with Fasttracker II clone v1.47
